@@ -33,7 +33,7 @@ KPluginFactory::Result<VpnUiPlugin> VpnUiPlugin::loadPluginForType(QObject *pare
         return md.value(QStringLiteral("X-NetworkManager-Services")) == serviceType;
     };
 
-    const QVector<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"), filter);
+    const QList<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"), filter);
 
     if (offers.isEmpty()) {
         KPluginFactory::Result<VpnUiPlugin> result;
@@ -133,3 +133,5 @@ VpnUiPlugin::ExportResult VpnUiPlugin::ExportResult::fail(const QString &errorMe
 
     return result;
 }
+
+#include "moc_vpnuiplugin.cpp"
